@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use experimental qw( signatures );
 
-our $VERSION = '0.029';
+our $VERSION = '0.030';
 
 use Mutex;
 use OpenTelemetry::Common;
@@ -39,7 +39,7 @@ use Exporter::Shiny qw(
     otel_untraced_context
 );
 
-my $logger = Log::Any->get_logger( category => 'OpenTelemetry' );
+my $logger = OpenTelemetry::Common::internal_logger;
 sub logger { $logger }
 sub _generate_otel_logger { \&logger }
 
