@@ -3,12 +3,12 @@ use Object::Pad ':experimental(init_expr)';
 
 package OpenTelemetry::Propagator::TraceContext::TraceFlags;
 
-our $VERSION = '0.029';
-
-use Log::Any;
-my $logger = Log::Any->get_logger( category => 'OpenTelemetry' );
+our $VERSION = '0.030';
 
 class OpenTelemetry::Propagator::TraceContext::TraceFlags {
+    use OpenTelemetry::Common ();
+    my $logger = OpenTelemetry::Common::internal_logger;
+
     field $flags :param :reader = 0;
 
     sub BUILDARGS ( $class, $flags = undef ) {
